@@ -8,6 +8,7 @@ from .corporate_cards  import CorporateCards
 from .reimbursements import Reimbursements
 from .tax_groups import TaxGroups
 from .merchants import Merchants
+from .files import Files
 
 __all__ = [
     'Expenses',
@@ -19,5 +20,6 @@ __all__ = [
     'CorporateCards',
     'Reimbursements',
     'TaxGroups',
-    'Merchants'
+    'Merchants',
+    'Files'
 ]
